using Godot;
using System;

public partial class balle : RigidBody3D
{
	[Export] public float force = 1f;
	Label cpt;
	AudioStream cubeSound;
	AudioStreamPlayer3D audioPlayer;
	
	public override void _Ready()
	{
		cpt = GetParent().GetNode("GUI/Compteur") as Label;
		cpt.Text = "0";
		audioPlayer = GetNode<AudioStreamPlayer3D>("AudioStreamPlayer3D");
		cubeSound = GD.Load("res://son_cube.wav") as AudioStream;
	}
	
	public int GetAxis(string axis)
	{
		// Si on effectue un mouvement horizontal
		if (axis == "horizontal")
		{
			// Flèche de gauche
			if (Input.IsActionPressed("ui_left"))
			  return -1;
			// Droite
			else if (Input.IsActionPressed("ui_right"))
			  return 1;
		}
		// Si vertical
		else if (axis == "vertical")
		{
			// Haut
			if (Input.IsActionPressed("ui_up"))
			  return -1;
			// Bas
			else if (Input.IsActionPressed("ui_down"))
			  return 1;
		}
		return 0;
	}

	public override void _PhysicsProcess(double delta)
	{
		// Mouvement en X
		int xSpeed = GetAxis("horizontal");
		// Mouvement en Y
		int ySpeed = GetAxis("vertical");
		// Vecteur 3 de direction
		var dir = new Vector3(xSpeed, 0, ySpeed).Normalized();
		// Pour la vitesse de mouvement
		float magnitude = force * (float)delta;
		// On applique la force de propulsion dans la direction * la force
		AddImpulse(magnitude * dir);
	}
	
	public void AddImpulse(Vector3 f)
	{
		// Si une force existe en X ou Y
		if (f[0] != 0 || f[2] != 0)
		{
			// On ajoute une impulsion à la balle
			ApplyCentralImpulse (f);
		}	
	}
	
	private void _on_area_3d_area_entered(Area3D area)
	{
		// Fin du niveau
		if (area.Name == "Fin")
		{
			GD.Print("Fin du niveau");
		}
		// Vide
		if (area.Name == "Vide")
		{
			GD.Print("Tombé !");
			GetTree().ReloadCurrentScene();
		}
	}
	
	private void _on_area_3d_body_entered(Node3D body)
	{
		if(body.Name != "Balle")
		{
			// Jouer un son
			audioPlayer.Stream = cubeSound;
			audioPlayer.Play();
			// Destruction du cube
			body.QueueFree();
			// Modification de la variable count du script Global
			var globalScript = GetNode<Global>("/root/Global");
			globalScript.IncreaseCount();
			GD.Print("New count : ");
			globalScript.PrintCount();
			// Affichage sur le GUI
			cpt.Text = globalScript.count.ToString();
		}
	}

}

